import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');
const height = +(svg.attr('height'));
const width = +(svg.attr('width'));

const render = data => {
  const xValue = d => d.Timestamp;
  const xAxisLabel = 'Timestamp';
  const yValue = d => d.Hotel_High_booking;
  const yAxisLabel = 'Hotel_High_booking';
  const title = 'High Hotel Booking Rate Over the Period of Time';
  const margin = { top: 40, right:80, bottom: 100, left:80 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);

  const xAxis = axisBottom(xScale)
    .tickSizeInner(-innerHeight)
    .tickPadding(10);

  const yAxis = axisLeft(yScale)
    .tickSizeInner(-innerWidth)
    .tickPadding(10);

  const yAxisG = g.append('g')
    .call(yAxis);

  yAxisG.selectAll('.domain')
    .remove();

  yAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('x', -innerHeight / 2)
    .attr('y', -60)
    .attr('fill', 'black')
    .attr('font-size', '14px')
    .attr('text-anchor', 'middle')
    .attr('transform', `rotate(-90)`)
    .text(yAxisLabel);

  const xAxisG = g.append('g')
    .call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);

  xAxisG.select('.domain').remove();

  xAxisG.append('text')
    .attr('class', 'axis-label')
    .attr('x', innerWidth / 2)
    .attr('y', 50)
    .attr('fill', 'black')

  
//Declaring the X-aix values and length.
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('x',innerWidth/2)
  	.attr('y',70)
    .attr('fill','black')
    .text(xAxisLabel)
  
//Using the line generator for line chart
  const lineGenerator = line()
  	.x(d =>xScale(xValue(d)))
  	.y(d=>yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('stroke','black')
  	.attr('d', lineGenerator(data))
  
  g.append('text')
  	.attr('class','title')
    .attr('x',innerWidth/2)
  	.attr('y',-10)
  	.attr('text-anchor','middle')
  	.text(title);
};
// Providing the Dataset URL
csv('https://gist.githubusercontent.com/rajasrilekkala/a5fcbb7c5dcf46f26883b20d06696958/raw/85821f5b52f12e2e09e06b8afe3705ec41615d85/Hotel%2520booking%2520Line%2520chart')
  .then(data =>{
    data.forEach(d =>{
      d.Hotel_High_booking= +d.Hotel_High_booking;
			d.Timestamp = new Date(d.Timestamp);
    });
    render(data);
});
